==> apache-beam-2.57.0-source-release.zip: beam-2.57.0/sdks/java/core/src/test/java/org/apache/beam/sdk/coders/StructuralByteArrayTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.sdk.coders;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;

import org.apache.beam.vendor.guava.v32_1_2_jre.com.google.common.base.Charsets;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.JUnit4;

/** Tests for {@link StructuralByteArray}. */
@RunWith(JUnit4.class)
public final class StructuralByteArrayTest {

  @Test
  public void testStructuralByteArray() throws Exception {
    assertEquals(
        new StructuralByteArray("test string".getBytes(Charsets.UTF_8)),
        new StructuralByteArray("test string".getBytes(Charsets.UTF_8)));
    assertFalse(
        new StructuralByteArray("test string".getBytes(Charsets.UTF_8))
            .equals(new StructuralByteArray("diff string".getBytes(Charsets.UTF_8))));
  }
}

==> apache-beam-2.61.0-source-release.zip: beam-2.61.0/sdks/java/core/src/test/java/org/apache/beam/sdk/coders/StructuralByteArrayTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.sdk.coders;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;

import java.nio.charset.StandardCharsets;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.JUnit4;

/** Tests for {@link StructuralByteArray}. */
@RunWith(JUnit4.class)
public final class StructuralByteArrayTest {

  @Test
  public void testStructuralByteArray() throws Exception {
    assertEquals(
        new StructuralByteArray("test string".getBytes(StandardCharsets.UTF_8)),
        new StructuralByteArray("test string".getBytes(StandardCharsets.UTF_8)));
    assertFalse(
        new StructuralByteArray("test string".getBytes(StandardCharsets.UTF_8))
            .equals(new StructuralByteArray("diff string".getBytes(StandardCharsets.UTF_8))));
  }
}
